@@ -2,10 +2,8 @@
 #'
 #' Software for registering functional data from the exponential family of distributions.
 #' 
-#' @name registr
 #' @author Julia Wrobel
-#' @docType package
 #'
 #' @useDynLib registr
 #' @importFrom Rcpp evalCpp
-NULL
+"_PACKAGE"
